@@ -28,18 +28,12 @@ class Country(ModelSQL, ModelView):
         ]
         self._order.insert(0, ('code', 'ASC'))
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', args[i][1], args[i][2])],
-                    limit=1, context=context)
-            if len(ids):
-                args2.append(('code', args[i][1], args[i][2]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code',) + clause[1:]], limit=1,
+                context=context)
+        if ids:
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def create(self, cursor, user, vals, context=None):
         if 'code' in vals and vals['code']:
@@ -161,18 +155,12 @@ class Subdivision(ModelSQL, ModelView):
         super(Subdivision, self).__init__()
         self._order.insert(0, ('code', 'ASC'))
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', args[i][1], args[i][2])],
-                    limit=1, context=context)
-            if len(ids):
-                args2.append(('code', args[i][1], args[i][2]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code',) + clause[1:]], limit=1,
+                context=context)
+        if ids:
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def create(self, cursor, user, vals, context=None):
         if 'code' in vals and vals['code']:
